@@ -1,5 +1,5 @@
 #
-# $Id: Splunk.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Splunk.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # api::splunk Brik
 #
@@ -13,8 +13,10 @@ use base qw(Metabrik::Client::Rest);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable rest api splunk) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable rest) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          output_mode => [ qw(json|xml) ],
          max_count => [ qw(max_count) ],
@@ -45,9 +47,7 @@ sub apps_local {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('apps_local'));
-   }
+   $self->brik_help_run_undef_arg('apps_local', $uri) or return;
 
    my $resp = $self->get($uri.'/services/apps/local') or return;
 
@@ -65,12 +65,8 @@ sub search_jobs {
    my ($search, $uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('search_jobs'));
-   }
-   if (! defined($search)) {
-      return $self->log->error($self->brik_help_run('search_jobs'));
-   }
+   $self->brik_help_run_undef_arg('search_jobs', $search) or return;
+   $self->brik_help_run_undef_arg('search_jobs', $uri) or return;
 
    my $resp = $self->post({ search => $search }, $uri.'/services/search/jobs') or return;
 
@@ -90,12 +86,8 @@ sub check_search_jobs_status {
    my ($sid, $uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('check_search_jobs_status'));
-   }
-   if (! defined($sid)) {
-      return $self->log->error($self->brik_help_run('check_search_jobs_status'));
-   }
+   $self->brik_help_run_undef_arg('check_search_jobs_status', $sid) or return;
+   $self->brik_help_run_undef_arg('check_search_jobs_status', $uri) or return;
 
    my $resp = $self->get($uri.'/services/search/jobs/'.$sid) or return;
 
@@ -115,12 +107,8 @@ sub get_search_jobs_content {
    my ($sid, $uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('get_search_jobs_content'));
-   }
-   if (! defined($sid)) {
-      return $self->log->error($self->brik_help_run('get_search_jobs_content'));
-   }
+   $self->brik_help_run_undef_arg('get_search_jobs_content', $sid) or return;
+   $self->brik_help_run_undef_arg('get_search_jobs_content', $uri) or return;
 
    my $resp = $self->get($uri.'/services/search/jobs/'.$sid.'/results/?output_mode=csv')
       or return;
@@ -139,9 +127,7 @@ sub licenser_groups {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('licenser_groups'));
-   }
+   $self->brik_help_run_undef_arg('licenser_groups', $uri) or return;
 
    my $resp = $self->get($uri.'/services/licenser/groups') or return;
 
@@ -164,7 +150,7 @@ Metabrik::Api::Splunk - api::splunk Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
