@@ -1,5 +1,5 @@
 #
-# $Id: Www.pm,v 443db6fb6411 2015/11/21 13:37:41 gomor $
+# $Id: Www.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # client::www Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Client::Www;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 443db6fb6411 $',
-      tags => [ qw(unstable browser http client www javascript screenshot) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable browser http javascript screenshot) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
          username => [ qw(username) ],
@@ -33,6 +35,7 @@ sub brik_properties {
          rtimeout => 10,
       },
       commands => {
+         install => [ ], # Inherited
          create_user_agent => [ ],
          reset_user_agent => [ ],
          get => [ qw(uri|OPTIONAL username|OPTIONAL password|OPTIONAL) ],
@@ -50,15 +53,17 @@ sub brik_properties {
          links => [ ],
          trace_redirect => [ qw(uri|OPTIONAL) ],
          screenshot => [ qw(uri output) ],
-         eval_javascript => [ qw(js uri|OPTIONAL) ],
-         info => [ ],
-         mirror => [ qw(url|$url_list output|OPTIONAL datadir|OPTIONAL) ],
+         eval_javascript => [ qw(js uri) ],
+         info => [ qw(uri|OPTIONAL) ],
+         mirror => [ qw(url|$url_list output datadir|OPTIONAL) ],
+         parse => [ qw(html) ],
       },
       require_modules => {
          'Progress::Any::Output' => [ ],
          'Progress::Any::Output::TermProgressBarColor' => [ ],
          'Net::SSL' => [ ],
          'Data::Dumper' => [ ],
+         'HTML::TreeBuilder' => [ ],
          'LWP::UserAgent' => [ ],
          'LWP::UserAgent::ProgressAny' => [ ],
          'HTTP::Request' => [ ],
@@ -72,6 +77,9 @@ sub brik_properties {
       optional_binaries => {
          'phantomjs' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(libssl-dev phantomjs) ],
+      },
    };
 }
 
@@ -143,9 +151,7 @@ sub _method {
    my ($uri, $username, $password, $method, $data) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run($method));
-   }
+   $self->brik_help_run_undef_arg($method, $uri) or return;
 
    $self->timeout(0);
 
@@ -206,9 +212,7 @@ sub post {
    my $self = shift;
    my ($href, $uri, $username, $password) = @_;
 
-   if (! defined($href)) {
-      return $self->log->error($self->brik_help_run('post'));
-   }
+   $self->brik_help_run_undef_arg('post', $href) or return;
 
    return $self->_method($uri, $username, $password, 'post', $href);
 }
@@ -217,9 +221,7 @@ sub put {
    my $self = shift;
    my ($href, $uri, $username, $password) = @_;
 
-   if (! defined($href)) {
-      return $self->log->error($self->brik_help_run('put'));
-   }
+   $self->brik_help_run_undef_arg('put', $href) or return;
 
    return $self->_method($uri, $username, $password, 'put', $href);
 }
@@ -228,9 +230,7 @@ sub patch {
    my $self = shift;
    my ($href, $uri, $username, $password) = @_;
 
-   if (! defined($href)) {
-      return $self->log->error($self->brik_help_run('patch'));
-   }
+   $self->brik_help_run_undef_arg('patch', $href) or return;
 
    return $self->_method($uri, $username, $password, 'patch', $href);
 }
@@ -261,7 +261,7 @@ sub code {
 
    my $last = $self->_last;
    if (! defined($last)) {
-      return $self->log->error("status: you have to execute a request first");
+      return $self->log->error("code: you have to execute a request first");
    }
 
    return $last->code;
@@ -331,7 +331,7 @@ sub forms {
 
    my $last = $self->_last;
    if (! defined($last)) {
-      return $self->log->error("links: you have to execute a request first");
+      return $self->log->error("forms: you have to execute a request first");
    }
 
    my $client = $self->_client;
@@ -340,25 +340,31 @@ sub forms {
       print Data::Dumper::Dumper($last->headers)."\n";
    }
 
+   my @result = ();
    my @forms = $client->forms;
-   my $count = 0; 
    for my $form (@forms) {
-      my $name = $form->{attr}->{name} || '(undef)';
-      print "$count: name: $name\n";
+      my $name = $form->{attr}{name} || 'undef';
+      my $action = $form->{action};
+      my $method = $form->{method} || 'undef';
+
+      my $h = {
+         action => $action,
+         method => $method,
+      };
 
       for my $input (@{$form->{inputs}}) {
-         print "   title:    ".$input->{title}."\n"    if exists $input->{title};
-         print "   type:     ".$input->{type}."\n"     if exists $input->{type};
-         print "   name:     ".$input->{name}."\n"     if exists $input->{name};
-         print "   value:    ".$input->{value}."\n"    if exists $input->{value};
-         print "   readonly: ".$input->{readonly}."\n" if exists $input->{readonly};
-         print "\n";
+         my $type = $input->{type} || '';
+         my $name = $input->{name} || '';
+         my $value = $input->{value} || '';
+         if ($type eq 'text') {
+            push @{$h->{input}}, $name;
+         }
       }
 
-      $count++;
+      push @result, $h;
    }
 
-   return $client;
+   return \@result;
 }
 
 sub trace_redirect {
@@ -366,9 +372,7 @@ sub trace_redirect {
    my ($uri, $username, $password) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_set('uri'));
-   }
+   $self->brik_help_run_undef_arg('trace_redirect', $uri) or return;
 
    my %args = ();
    if (! $self->ssl_verify) {
@@ -423,9 +427,8 @@ sub screenshot {
    my $self = shift;
    my ($uri, $output) = @_;
 
-   if (! defined($uri) || ! defined($output)) {
-      return $self->log->error($self->brik_help_run('screenshot'));
-   }
+   $self->brik_help_run_undef_arg('screenshot', $uri) or return;
+   $self->brik_help_run_undef_arg('screenshot', $output) or return;
 
    if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
    &&  $self->brik_has_binary('phantomjs')) {
@@ -457,9 +460,8 @@ sub eval_javascript {
    my $self = shift;
    my ($js, $uri) = @_;
 
-   if (! defined($js) || ! defined($uri)) {
-      return $self->log->error($self->brik_help_run('eval_javascript'));
-   }
+   $self->brik_help_run_undef_arg('eval_javascript', $js) or return;
+   $self->brik_help_run_undef_arg('eval_javascript', $uri) or return;
 
    # Perl module Wight may also be an option.
 
@@ -482,13 +484,13 @@ sub eval_javascript {
 
 sub info {
    my $self = shift;
+   my ($uri) = @_;
 
-   if (! defined($self->mechanize)) {
-      return $self->log->error($self->brik_help_run('get'));
-   }
+   $uri ||= $self->uri;
+   $self->brik_help_run_undef_arg('info', $uri) or return;
 
-   my $mech = $self->mechanize;
-   my $headers = $mech->response->headers;
+   my $r = $self->get($uri) or return;
+   my $headers = $r->{headers};
 
    # Taken from apps.json from Wappalyzer
    my @headers = qw(
@@ -542,7 +544,7 @@ sub info {
       $info{$hdr} = $this if defined($this);
    }
 
-   my $title = $mech->title;
+   my $title = $r->{title};
    if (defined($title)) {
       print "Title: $title\n";
    }
@@ -551,18 +553,16 @@ sub info {
       print "$k: ".$info{$k}."\n";
    }
 
-   return $mech;
+   return 1;
 }
 
 sub mirror {
    my $self = shift;
    my ($url, $output, $datadir) = @_;
 
-   if (! defined($url) || ! defined($output)) {
-      return $self->log->error($self->brik_help_run('mirror'));
-   }
-
    $datadir ||= $self->datadir;
+   $self->brik_help_run_undef_arg('mirror', $url) or return;
+   $self->brik_help_run_undef_arg('mirror', $output) or return;
 
    my @files = ();
    if (ref($url) eq 'ARRAY') {
@@ -591,19 +591,31 @@ sub mirror {
          return $self->log->error("mirror: mirroring URL [$url] to local file [$output] failed: $@");
       }
       my $code = $rc->code;
-      if ($rc->code == 200) {
+      if ($code == 200) {
          my $file = $datadir.'/'.$output;
          push @files, $file;
          $self->log->info("mirror: downloading URL [$url] to local file [$file] done");
       }
-      elsif ($rc->code == 304) { # Not modified
+      elsif ($code == 304) { # Not modified
          $self->log->info("mirror: file [$output] not modified since last check");
       }
+      else {
+         return $self->log->error("mirror: error while mirroring URL [$url] with code: [$code]");
+      }
    }
 
    return \@files;
 }
 
+sub parse {
+   my $self = shift;
+   my ($html) = @_;
+
+   $self->brik_help_run_undef_arg('parse', $html) or return;
+
+   return HTML::TreeBuilder->new_from_content($html);
+}
+
 1;
 
 __END__
@@ -614,7 +626,7 @@ Metabrik::Client::Www - client::www Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
