@@ -1,5 +1,5 @@
 #
-# $Id: Cwe.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Cwe.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::cwe Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Database::Cwe;
 use strict;
 use warnings;
 
-use base qw(Metabrik::File::Fetch);
+use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable cve cwe) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable cve) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          file => [ qw(file) ],
@@ -39,15 +41,15 @@ sub update {
    my $datadir = $self->datadir;
 
    my $uri = 'http://cwe.mitre.org/data/xml/views/2000.xml.zip';
-   my $file = "$datadir/2000.xml.zip";
+   my $file = "2000.xml.zip";
 
-   $self->get($uri, $file)
-      or return $self->log->error("update: get failed");
+   my $files = $self->mirror($uri, $file, $datadir) or return;
+   if (@$files == 0) {  # Nothing new
+      return $datadir;
+   }
 
-   my $file_compress = Metabrik::File::Compress->new_from_brik($self) or return;
-
-   $file_compress->unzip($file, $datadir)
-      or return $self->log->error("update: unzip failed");
+   my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
+   $fc->unzip($datadir.'/'.$file, $datadir) or return;
 
    return $datadir;
 }
@@ -57,15 +59,14 @@ sub load {
    my ($file) = @_;
 
    $file ||= $self->file;
-   if (! -f $file) {
-      return $self->log->error("load: file [$file] not found");
-   }
+   $self->brik_help_run_undef_arg('load', $file) or return;
+   $self->brik_help_run_file_not_found('load', $file) or return;
 
    my $datadir = $self->datadir;
 
-   my $file_xml = Metabrik::File::Xml->new_from_brik($self) or return;
+   my $fx = Metabrik::File::Xml->new_from_brik_init($self) or return;
 
-   my $xml = $file_xml->read($datadir.'/'.$file);
+   my $xml = $fx->read($datadir.'/'.$file) or return;
 
    return $self->xml($xml);
 }
@@ -74,6 +75,9 @@ sub show {
    my $self = shift;
    my ($h) = @_;
 
+   $self->brik_help_run_undef_arg('show', $h) or return;
+   $self->brik_help_run_invalid_arg('show', $h, 'HASH') or return;
+
    my $buf = "ID: ".$h->{id}."\n";
    $buf .= "Type: ".$h->{type}."\n";
    $buf .= "Name: ".$h->{name}."\n";
@@ -147,15 +151,9 @@ sub search {
    my $self = shift;
    my ($pattern) = @_;
 
-   if (! defined($self->xml)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-
-   if (! defined($pattern)) {
-      return $self->log->error($self->brik_help_run('search'));
-   }
-
    my $xml = $self->xml;
+   $self->brik_help_run_undef_arg('load', $xml) or return;
+   $self->brik_help_run_undef_arg('search', $pattern) or return;
 
    my @list = ();
    if (exists $xml->{Weaknesses} && exists $xml->{Weaknesses}->{Weakness}) {
@@ -195,7 +193,7 @@ Metabrik::Database::Cwe - database::cwe Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
