@@ -1,5 +1,5 @@
 #
-# $Id: Nvd.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Nvd.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::nvd Brik
 #
@@ -7,25 +7,27 @@ package Metabrik::Database::Nvd;
 use strict;
 use warnings;
 
-use base qw(Metabrik::File::Fetch);
+use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
-      tags => [ qw(unstable cve cpe nvd nist) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable cve cpe nist) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          loaded_xml => [ qw(loaded_xml) ],
       },
       commands => {
-         update => [ qw(recent|modified|others|all RETURN:xml_filenames) ],
-         load => [ qw(recent|modified|others|all year|OPTIONAL RETURN:xml) ],
-         search_all => [ qw(RETURN:all_entries_list) ],
-         cve_search => [ qw(pattern RETURN:entries_list) ],
-         cpe_search => [ qw(pattern RETURN:entries_list) ],
-         get_cve_xml => [ qw(cve_id RETURN:entry_xml) ],
-         to_hash => [ qw(entry_xml RETURN:entry_hash) ],
-         to_string => [ qw(entry_hash RETURN:lines_list) ],
+         update => [ qw(recent|modified|others|all) ],
+         load => [ qw(recent|modified|others|all year|OPTIONAL) ],
+         search_all => [ ],
+         cve_search => [ qw(pattern) ],
+         cpe_search => [ qw(pattern) ],
+         get_cve_xml => [ qw(cve_id) ],
+         to_hash => [ qw(entry_xml) ],
+         to_string => [ qw(entry_hash) ],
          print => [ qw(entry_hash) ],
       },
       require_modules => {
@@ -68,15 +70,15 @@ sub update {
 
    my $datadir = $self->datadir;
 
-   my $compress = Metabrik::File::Compress->new_from_brik($self) or return;
+   my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
 
    if ($type eq 'recent') {
       (my $uri = $resource->{uri}) =~ s/NAME/Recent/;
       (my $gz = $resource->{gz}) =~ s/NAME/Recent/;
       (my $xml = $resource->{xml}) =~ s/NAME/Recent/;
       my $output = "$datadir/$gz";
-      $self->get($uri, $output) or return $self->log->error("update: get failed");
-      $compress->gunzip($output, $datadir.'/'.$xml) or return $self->log->error("update: gunzip failed");
+      $self->mirror($uri, $gz, $datadir) or return;
+      $fc->gunzip($output, $xml, $datadir) or return;
       return $datadir.'/'.$xml;
    }
    elsif ($type eq 'modified') {
@@ -84,8 +86,8 @@ sub update {
       (my $gz = $resource->{gz}) =~ s/NAME/Modified/;
       (my $xml = $resource->{xml}) =~ s/NAME/Modified/;
       my $output = "$datadir/$gz";
-      $self->get($uri, $output) or return $self->log->error("update: get failed");
-      $compress->gunzip($output, $datadir.'/'.$xml) or return $self->log->error("update: gunzip failed");
+      $self->mirror($uri, $gz, $datadir) or return;
+      $fc->gunzip($output, $xml, $datadir) or return;
       return $datadir.'/'.$xml;
    }
    elsif ($type eq 'others') {
@@ -95,8 +97,8 @@ sub update {
          (my $gz = $resource->{gz}) =~ s/NAME/$year/;
          (my $xml = $resource->{xml}) =~ s/NAME/$year/;
          my $output = "$datadir/$gz";
-         $self->get($uri, $output) or return $self->log->error("update: get failed");
-         $compress->gunzip($output, $datadir.'/'.$xml) or return $self->log->error("update: gunzip failed");
+         $self->mirror($uri, $gz, $datadir) or return;
+         $fc->gunzip($output, $xml, $datadir) or return;
          push @output, $datadir.'/'.$xml;
       }
       return \@output;
@@ -157,7 +159,7 @@ sub load {
 
    my $datadir = $self->datadir;
 
-   my $brik_xml = Metabrik::File::Xml->new_from_brik($self) or return;
+   my $fx = Metabrik::File::Xml->new_from_brik_init($self) or return;
 
    my $old = $self->loaded_xml;
 
@@ -165,7 +167,7 @@ sub load {
       (my $xml = $resource->{xml}) =~ s/NAME/Recent/;
       my $file = $datadir.'/'.$xml;
 
-      my $new = $brik_xml->read($file) or return $self->log->error("load: read failed");
+      my $new = $fx->read($file) or return;
 
       my $merged = $self->_merge_xml($old, $new, $type);
 
@@ -175,7 +177,7 @@ sub load {
       (my $xml = $resource->{xml}) =~ s/NAME/Modified/;
       my $file = $datadir.'/'.$xml;
 
-      my $new = $brik_xml->read($file) or return $self->log->error("load: read failed");
+      my $new = $fx->read($file) or return;
 
       my $merged = $self->_merge_xml($old, $new, $type);
 
@@ -188,7 +190,7 @@ sub load {
          (my $xml = $resource->{xml}) =~ s/NAME/$year/;
          my $file = $datadir.'/'.$xml;
 
-         my $new = $brik_xml->read($file) or return $self->log->error("load: read failed");
+         my $new = $fx->read($file);
 
          $merged = $self->_merge_xml($merged, $new, $type);
       }
@@ -223,9 +225,8 @@ sub print {
    my $self = shift;
    my ($h) = @_;
 
-   if (! defined($h)) {
-      return $self->log->error($self->brik_help_run('print'));
-   }
+   $self->brik_help_run_undef_arg('print', $h) or return;
+   $self->brik_help_run_invalid_arg('print', $h, 'HASH') or return;
 
    my $lines = $self->to_string($h);
    for my $line (@$lines) {
@@ -239,6 +240,9 @@ sub to_hash {
    my $self = shift;
    my ($h) = @_;
 
+   $self->brik_help_run_undef_arg('to_hash', $h) or return;
+   $self->brik_help_run_invalid_arg('to_hash', $h, 'HASH') or return;
+
    my $cve = $h->{'vuln:cve-id'};
 
    my $published_datetime = $h->{'vuln:published-datetime'};
@@ -274,9 +278,7 @@ sub search_all {
    my $self = shift;
 
    my $xml = $self->loaded_xml;
-   if (! defined($xml)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
+   $self->brik_help_run_undef_arg('load', $xml) or return;
 
    my $entries = $xml->{entry};
    if (! defined($entries)) {
@@ -297,13 +299,8 @@ sub cve_search {
    my ($pattern) = @_;
 
    my $xml = $self->loaded_xml;
-   if (! defined($xml)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-
-   if (! defined($pattern)) {
-      return $self->log->error($self->brik_help_run('cve_search'));
-   }
+   $self->brik_help_run_undef_arg('load', $xml) or return;
+   $self->brik_help_run_undef_arg('cve_search', $pattern) or return;
 
    my $entries = $xml->{entry};
    if (! defined($entries)) {
@@ -328,13 +325,8 @@ sub cpe_search {
    my ($cpe) = @_;
 
    my $xml = $self->loaded_xml;
-   if (! defined($xml)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-
-   if (! defined($cpe)) {
-      return $self->log->error($self->brik_help_run('cpe_search'));
-   }
+   $self->brik_help_run_undef_arg('load', $xml) or return;
+   $self->brik_help_run_undef_arg('cpe_search', $cpe) or return;
 
    my $entries = $xml->{entry};
    if (! defined($entries)) {
@@ -362,9 +354,7 @@ sub get_cve_xml {
    my ($cve_id) = @_;
 
    my $xml = $self->loaded_xml;
-   if (! defined($xml)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
+   $self->brik_help_run_undef_arg('load', $xml) or return;
 
    if (defined($xml->{entry})) {
       return $xml->{entry}->{$cve_id};
@@ -383,7 +373,7 @@ Metabrik::Database::Nvd - database::nvd Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
