@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v 4f8333db5069 2015/11/19 07:36:05 gomor $
+# $Id: Compress.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::zip brik
 #
@@ -7,29 +7,39 @@ package Metabrik::File::Compress;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Shell::Command);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4f8333db5069 $',
-      tags => [ qw(unstable compress unzip gunzip uncompress) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable gzip unzip gunzip uncompress) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(directory) ],
          input => [ qw(file) ],
          output => [ qw(file) ],
       },
+      attributes_default => {
+         datadir => '.', # Uncompress in current directory by default
+      },
       commands => {
+         install => [ ], # Inherited
          unzip => [ qw(input|OPTIONAL datadir|OPTIONAL) ],
          gunzip => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
          uncompress => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
       },
       require_modules => {
-         'Metabrik::File::Write' => [ ],
          'Compress::Zlib' => [ ],
+         'Metabrik::File::Type' => [ ],
+         'Metabrik::File::Write' => [ ],
       },
       require_binaries => {
          'unzip' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(unzip) ],
+      },
    };
 }
 
@@ -38,11 +48,8 @@ sub unzip {
    my ($input, $datadir) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('unzip'));
-   }
-
    $datadir ||= $self->datadir;
+   $self->brik_help_run_undef_arg('unzip', $input) or return;
 
    my $cmd = "unzip -o $input -d $datadir/";
 
@@ -56,18 +63,15 @@ sub gunzip {
    my ($input, $output, $datadir) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('gunzip'));
-   }
-
    $output ||= $self->output;
-   # If no output given, we used the input file name by removing .gz like gunzip command
+   $datadir ||= $self->datadir;
+   $self->brik_help_run_undef_arg('gunzip', $input) or return;
+
+   # If no output given, we use the input file name by removing .gz like gunzip command
    if (! defined($output)) {
       ($output = $input) =~ s/.gz$//;
    }
 
-   $datadir ||= $self->datadir;
-
    my $gz = Compress::Zlib::gzopen($input, "rb");
    if (! $gz) {
       return $self->log->error("gunzip: gzopen file [$input]: [$Compress::Zlib::gzerrno]");
@@ -78,10 +82,7 @@ sub gunzip {
    $fw->encoding('ascii');
    $fw->overwrite(1);
 
-   my $fd = $fw->open($datadir.'/'.$output);
-   if (! defined($fd)) {
-      return $self->log->error("gunzip: open failed");
-   }
+   my $fd = $fw->open($datadir.'/'.$output) or return;
 
    my $no_error = 1;
    my $buffer = '';
@@ -96,9 +97,13 @@ sub gunzip {
       }
    }
 
+   if (! $no_error) {
+      $self->log->warning("gunzip: had some errors during gunzipping");
+   }
+
    $fw->close;
 
-   return $no_error;
+   return $output;
 }
 
 sub uncompress {
@@ -106,20 +111,22 @@ sub uncompress {
    my ($input, $output, $datadir) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('uncompress'));
-   }
-
    $datadir ||= $self->datadir;
+   $self->brik_help_run_undef_arg('uncompress', $input) or return;
 
-   if ($input =~ /\.gz$/) {
+   my $ft = Metabrik::File::Type->new_from_brik_init($self) or return;
+   my $type = $ft->get_mime_type($input) or return;
+
+   if ($type eq 'application/gzip') {
       return $self->gunzip($input, $output, $datadir);
    }
-   elsif ($input =~ /\.zip$/) {
+   elsif ($type eq 'application/zip'
+   ||     $type eq 'application/vnd.oasis.opendocument.text'
+   ||     $type eq 'application/java-archive') {
       return $self->unzip($input, $datadir);
    }
 
-   return $self->log->error("uncompress: don't know how to uncompress file [$input]");
+   return $self->log->error("uncompress: don't know how to uncompress file [$input] with MIME type [$type]");
 }
 
 1;
@@ -132,7 +139,7 @@ Metabrik::File::Compress - file::compress Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
