@@ -1,5 +1,5 @@
 #
-# $Id: Ole.pm,v c6019afba057 2015/10/27 18:56:35 gomor $
+# $Id: Ole.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::ole Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::File::Ole;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Shell::Command);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: c6019afba057 $',
-      tags => [ qw(unstable file ole read) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable read) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          input => [ qw(file) ],
          output => [ qw(file) ],
@@ -22,39 +24,34 @@ sub brik_properties {
          olevba => '/usr/local/lib/python2.7/dist-packages/oletools/olevba.py',
       },
       commands => {
-         install => [ ],
+         install => [ ], # Inherited
          extract_vbs => [ qw(input|OPTIONAL output|OPTIONAL) ],
       },
       require_modules => {
+         'Metabrik::File::Text' => [ ],
          'Metabrik::System::Os' => [ ],
          'Metabrik::System::Package' => [ ],
-         'Metabrik::File::Text' => [ ],
       },
       require_binaries => {
          'python' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(python python-pip) ],
+      },
    };
 }
 
 sub install {
    my $self = shift;
 
-   my $so = Metabrik::System::Os->new_from_brik_init($self) or return;
-   my $distrib = $so->distribution or return;
-   my $os = $distrib->{name};
+   # Install system dependant packages
+   $self->SUPER::install or return;
 
-   if ($os eq 'Ubuntu') {
-      my $sp = Metabrik::System::Package->new_from_brik_init($self) or return;
-      $sp->install('python-pip') or return;
-
-      my $prev = $self->use_sudo;
-      $self->use_sudo(1);
-      $self->system('pip install oletools --upgrade');
-      $self->use_sudo($prev);
-   }
-   else {
-      return $self->log->error("install: OS [$os] not supported for install Command");
-   }
+   # Then Python dependant packages
+   my $prev = $self->use_sudo;
+   $self->use_sudo(1);
+   $self->system('pip install oletools --upgrade');
+   $self->use_sudo($prev);
 
    return 1;
 }
@@ -65,22 +62,13 @@ sub extract_vbs {
 
    $input ||= $self->input;
    $output ||= $self->output;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('extract_vbs'));
-   }
-   if (! defined($output)) {
-      return $self->log->error($self->brik_help_run('extract_vbs'));
-   }
-
    my $olevba = $self->olevba;
-   if (! -f $olevba) {
-      return $self->log->error("extract_vbs: olevba.py not found at [$olevba]");
-   }
+   $self->brik_help_run_undef_arg('extract_vbs', $input) or return;
+   $self->brik_help_run_undef_arg('extract_vbs', $output) or return;
+   $self->brik_help_run_file_not_found('extract_vbs', $olevba) or return;
 
    my $out = $self->capture("python $olevba $input");
 
-   #for (@$out) { print "LINE[$_]\n"; }
-
    my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
    $ft->write($out, $output) or return;
 
@@ -97,7 +85,7 @@ Metabrik::File::Ole - file::ole Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
