@@ -1,5 +1,5 @@
 #
-# $Id: Arp.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
+# $Id: Arp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::arp Brik
 #
@@ -7,16 +7,18 @@ package Metabrik::Network::Arp;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Network::Frame);
+use base qw(Metabrik::Network::Frame Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4a548f1412b7 $',
-      tags => [ qw(unstable arp cache poison eui64 discover scan) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable cache poison eui64 discover scan eui-64) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          try => [ qw(try_count) ],
          rtimeout => [ qw(timeout_seconds) ],
-         max_read => [ qw(max_read_packet) ],
+         count => [ qw(count) ],
          max_runtime => [ qw(max_runtime) ],
          device => [ qw(device) ],
          _pidfile => [ qw(INTERNAL) ],
@@ -26,6 +28,7 @@ sub brik_properties {
          rtimeout => 2,
       },
       commands => {
+         install => [ ], # Inherited
          cache => [ ],
          half_poison => [ qw(gateway victim|OPTIONAL device|OPTIONAL) ],
          full_poison => [ qw(gateway victim|OPTIONAL device|OPTIONAL) ],
@@ -49,6 +52,9 @@ sub brik_properties {
       optional_binaries => {
          'arpspoof' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(dsniff libnet-libdnet-perl) ],
+      },
    };
 }
 
@@ -91,9 +97,8 @@ sub half_poison {
    }
 
    $device ||= $self->device;
-   if (! defined($gateway)) {
-      return $self->log->error($self->brik_help_run('half_poison'))
-   }
+   $self->brik_help_run_undef_arg('half_poison', $gateway) or return;
+   $self->brik_help_run_undef_arg('half_poison', $device) or return;
 
    my $cmd = "arpspoof -i $device -c both";
    $cmd .= " -t $victim" if defined($victim);  # Or default to all LAN hosts
@@ -118,9 +123,8 @@ sub full_poison {
    }
 
    $device ||= $self->device;
-   if (! defined($gateway)) {
-      return $self->log->error($self->brik_help_run('full_poison'))
-   }
+   $self->brik_help_run_undef_arg('full_poison', $gateway) or return;
+   $self->brik_help_run_undef_arg('full_poison', $device) or return;
 
    my $cmd = "arpspoof -i $device -c both -r";
    $cmd .= " -t $victim" if defined($victim);  # Or default to all LAN hosts
@@ -141,9 +145,7 @@ sub mac2eui64 {
    my $self = shift;
    my ($mac) = @_;
 
-   if (! defined($mac)) {
-      return $self->log->error($self->brik_help_run('mac2eui64'));
-   }
+   $self->brik_help_run_undef_arg('mac2eui64', $mac) or return;
 
    if ($mac !~ /^[0-9a-z]{2}:[0-9a-z]{2}:[0-9a-z]{2}:[0-9a-z]{2}:[0-9a-z]{2}:[0-9a-z]{2}$/i) {
       return $self->log->error("mac2eui64: invalid MAC address [$mac]");
@@ -173,42 +175,41 @@ sub scan {
    my $self = shift;
    my ($subnet, $device) = @_;
 
-   if ($< != 0) {
-      return $self->log->error("scan: must be root to run");
-   }
+   $self->brik_help_run_must_be_root('scan') or return;
+
+   $device ||= $self->device;
+   $self->brik_help_run_undef_arg('scan', $device) or return;
 
    my $interface = $self->get_device_info($device) or return;
 
    $subnet ||= $interface->{subnet4};
-   if (! defined($subnet)) {
-      return $self->log->error($self->brik_help_run('scan'));
-   }
+   $self->brik_help_run_undef_arg('scan', $subnet) or return;
 
    my $arp_cache = $self->cache
       or return $self->log->error("scan: cache failed");
 
+   my $scan_arp_cache = {};
+   for my $this (keys %{$arp_cache->{mac}}) {
+      my $mac = $this;
+      my $ip = $arp_cache->{mac}{$this};
+      $self->log->verbose("scan: found MAC [$mac] in cache for IPv4 [$ip]");
+      $scan_arp_cache->{$ip} = $mac;
+   }
+
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
 
    my $ip_list = $na->ipv4_list($subnet) or return;
 
    my $reply_cache = {};
-   my $local_arp_cache = {};
    my @frame_list = ();
-
    for my $ip (@$ip_list) {
       # We scan ARP for everyone but our own IP
       if (exists($interface->{ipv4}) && $ip eq $interface->{ipv4}) {
          next;
       }
 
-      my $mac;
-      if (exists($local_arp_cache->{$ip})) {
-         $mac = $local_arp_cache->{$ip};
-         $reply_cache->{$ip} = $mac;
-      }
-      elsif ($mac = $arp_cache->{$ip}) {
-         $self->log->verbose("scan: found mac [$mac] for ipv4 [$ip] in ARP cache");
-         $local_arp_cache->{$ip} = $mac;
+      if (exists($scan_arp_cache->{$ip})) {
+         my $mac = $scan_arp_cache->{$ip};
          $reply_cache->{$ip} = $mac;
       }
       else {
@@ -223,7 +224,7 @@ sub scan {
 
    my $nr = Metabrik::Network::Read->new_from_brik_init($self) or return;
    $nr->rtimeout($self->rtimeout);
-   $nr->max_read($self->max_read || 0);
+   $nr->count($self->count || 0);
 
    my $filter = 'arp and src net '.$subnet.' and dst host '.$interface->{ipv4};
    my $read = $nr->open(2, $interface->{device}, $filter) or return;
@@ -254,11 +255,11 @@ sub scan {
          my $src_ip = $r->ref->{ARP}->srcIp;
          if (! exists($reply_cache->{$src_ip})) {
             my $mac = $r->ref->{ARP}->src;
-            $self->log->info("scan: received mac [$mac] for ipv4 [$src_ip]");
+            $self->log->info("scan: received MAC [$mac] for IPV4 [$src_ip]");
             $reply_cache->{$src_ip} = $r->ref->{ARP}->src;
 
             # Put it in ARP cache table for next round
-            $local_arp_cache->{$src_ip} = $mac;
+            $scan_arp_cache->{$src_ip} = $mac;
          }
       }
 
@@ -279,24 +280,14 @@ sub scan {
       $results{by_ipv6}{$ip6} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
    }
 
-   # And complete with the cache table
-   for (keys %{$arp_cache->{mac}}) {
-      my $mac = $_;
-      my $ip4 = $arp_cache->{mac}{$_};
-      my $ip6 = $self->mac2eui64($mac);
-      $results{by_mac}{$mac} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
-      $results{by_ipv4}{$ip4} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
-      $results{by_ipv6}{$ip6} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
-   }
-
    return \%results;
 }
 
 sub get_ipv4_neighbors {
    my $self = shift;
-   my ($subnet) = @_;
+   my ($subnet, $device) = @_;
 
-   my $scan = $self->scan($subnet) or return;
+   my $scan = $self->scan($subnet, $device) or return;
    my $ipv4 = $scan->{by_ipv4};
    if (! defined($ipv4)) {
       return $self->log->info("get_ipv4_neighbors: no IPv4 neighbor found");
@@ -307,9 +298,9 @@ sub get_ipv4_neighbors {
 
 sub get_ipv6_neighbors {
    my $self = shift;
-   my ($subnet) = @_;
+   my ($subnet, $device) = @_;
 
-   my $scan = $self->scan($subnet) or return;
+   my $scan = $self->scan($subnet, $device) or return;
    my $ipv6 = $scan->{by_ipv6};
    if (! defined($ipv6)) {
       return $self->log->info("get_ipv6_neighbors: no IPv6 neighbor found");
@@ -320,9 +311,9 @@ sub get_ipv6_neighbors {
 
 sub get_mac_neighbors {
    my $self = shift;
-   my ($subnet) = @_;
+   my ($subnet, $device) = @_;
 
-   my $scan = $self->scan($subnet) or return;
+   my $scan = $self->scan($subnet, $device) or return;
    my $mac = $scan->{by_mac};
    if (! defined($mac)) {
       return $self->log->info("get_mac_neighbors: no MAC neighbor found");
@@ -362,7 +353,7 @@ Metabrik::Network::Arp - network::arp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
