@@ -1,5 +1,5 @@
 #
-# $Id: Tor.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Tor.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::tor Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable tor exitnodes) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable exitnodes) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
       },
@@ -35,20 +37,13 @@ sub brik_properties {
 sub exit_nodes_list {
    my $self = shift;
 
-   my $get = $self->get or return $self->log->error('exit_nodes_list: get failed');
+   my $get = $self->get or return;
 
    my $ip_list = $get->{content};
 
    my @ip_list = split(/\n/, $ip_list);
-   my %ip_list = ();
-   for my $ip (@ip_list) {
-      $ip_list{$ip} = 1;
-   }
 
-   return {
-      as_list => \@ip_list,
-      as_hash => \%ip_list,
-   };
+   return \@ip_list;
 }
 
 1;
@@ -61,7 +56,7 @@ Metabrik::Network::Tor - network::tor Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
