@@ -1,11 +1,13 @@
 #
-# $Id: Repository.pm,v 3595633d3216 2015/10/29 21:25:42 gomor $
+# $Id: Repository.pm,v ecface00b50a 2016/01/02 17:50:23 gomor $
 #
 package Metabrik::Repository;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+# Breaking.Feature.Fix
+our $VERSION = '1.20';
+our $FIX = '0';
 
 1;
 
@@ -17,7 +19,7 @@ Metabrik::Repository - Metabrik Briks repository
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
