@@ -1,5 +1,5 @@
 #
-# $Id: Uri.pm,v c09a1208077b 2015/10/16 16:37:13 gomor $
+# $Id: Uri.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::uri Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: c09a1208077b $',
-      tags => [ qw(unstable uri string) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
       },
@@ -33,9 +35,12 @@ sub brik_properties {
          query_form => [ ],
          userinfo => [ ],
          is_https_scheme => [ ],
+         encode => [ qw($data) ],
+         decode => [ qw($data) ],
       },
       require_modules => {
          'URI' => [ ],
+         'URI::Escape' => [ ],
       },
    };
 }
@@ -45,9 +50,7 @@ sub parse {
    my ($string) = @_;
 
    $string ||= $self->uri;
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_set('uri'));
-   }
+   $self->brik_help_run_undef_arg('parse', $string) or return;
 
    my $uri = URI->new($string);
 
@@ -75,9 +78,8 @@ sub is_https_scheme {
    my $self = shift;
    my ($parsed) = @_;
 
-   if (! defined($parsed)) {
-      return $self->log->error($self->brik_help_run('is_https_scheme'));
-   }
+   $self->brik_help_run_undef_arg('is_https_scheme', $parsed) or return;
+   $self->brik_help_run_invalid_arg('is_https_scheme', $parsed, 'HASH') or return;
 
    if (exists($parsed->{scheme}) && $parsed->{scheme} eq 'https') {
       return 1;
@@ -91,9 +93,7 @@ sub _this {
    my ($this) = @_;
 
    my $uri = $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('parse'));
-   }
+   $self->brik_help_run_undef_arg('parse', $uri) or return;
 
    return $uri->$this;
 }
@@ -110,6 +110,28 @@ sub authority { return shift->_this('authority'); }
 sub query_form { return shift->_this('query_form'); }
 sub userinfo { return shift->_this('userinfo'); }
 
+sub encode {
+   my $self = shift;
+   my ($data) = @_;
+
+   $self->brik_help_run_undef_arg('encode', $data) or return;
+
+   my $encoded = URI::Escape::uri_escape($data);
+
+   return $encoded;
+}
+
+sub decode {
+   my $self = shift;
+   my ($data) = @_;
+
+   $self->brik_help_run_undef_arg('decode', $data) or return;
+
+   my $decoded = URI::Escape::uri_unescape($data);
+
+   return $decoded;
+}
+
 1;
 
 __END__
@@ -120,7 +142,7 @@ Metabrik::String::Uri - string::uri Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
