@@ -1,5 +1,5 @@
 #
-# $Id: Os.pm,v 39f1159c4a8c 2015/02/17 06:45:33 gomor $
+# $Id: Os.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # system::os brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 39f1159c4a8c $',
-      tags => [ qw(unstable os uname linux freebsd distribution) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable uname linux freebsd distribution) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          _uname => [ qw(INTERNAL) ],
       },
@@ -23,6 +25,11 @@ sub brik_properties {
          hostname => [ ],
          arch => [ ],
          distribution => [ ],
+         is => [ qw(os) ],
+         is_ubuntu => [ ],
+         is_linux => [ ],
+         is_freebsd => [ ],
+         my => [ ],
       },
       require_modules => {
          'POSIX' => [ ],
@@ -103,7 +110,7 @@ sub distribution {
    my $release = $self->release;
 
    if ($name eq 'Linux') {
-      my $ft = Metabrik::File::Text->new_from_brik($self) or return;
+      my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
       $ft->as_array(1);
       $ft->strip_crlf(1);
 
@@ -139,6 +146,67 @@ sub distribution {
    };
 }
 
+sub is {
+   my $self = shift;
+   my ($os) = @_;
+
+   $self->brik_help_run_undef_arg('is', $os) or return;
+
+   $os = lc($os);
+
+   my $name = $self->name or return;
+   my $distrib = $self->distribution or return;
+   if (exists($distrib->{name})) {
+      my $this = lc($distrib->{name});
+      if ($this eq $os) {
+         return 1;
+      }
+   }
+   if (defined($name)) {
+      my $this = lc($name);
+      if ($this eq $os) {
+         return 1;
+      }
+   }
+
+   return 0;
+}
+
+sub is_ubuntu {
+   my $self = shift;
+
+   return $self->is('ubuntu');
+}
+
+sub is_linux {
+   my $self = shift;
+
+   return $self->is('linux');
+}
+
+sub is_freebsd {
+   my $self = shift;
+
+   return $self->is('freebsd');
+}
+
+sub my {
+   my $self = shift;
+
+   my $name = $self->name or return;
+   my $distrib = $self->distribution or return;
+   if (exists($distrib->{name})) {
+      my $this = lc($distrib->{name});
+      return $this;
+   }
+   if (defined($name)) {
+      my $this = lc($name);
+      return $this;
+   }
+
+   return 'undef';
+}
+
 1;
 
 __END__
@@ -149,7 +217,7 @@ Metabrik::System::os - system::os Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
